aboutsummaryrefslogtreecommitdiffstats
path: root/src/vnet/bier
diff options
context:
space:
mode:
authorPaul Vinciguerra <pvinci@vinciconsulting.com>2019-03-27 11:25:48 -0700
committerNeale Ranns <nranns@cisco.com>2019-03-28 06:36:04 +0000
commit8feeaff56fa9a4fbdfc06131f28a1060ffd9645d (patch)
tree76ab4368d46a40288e01aa46624470145c64524e /src/vnet/bier
parent64f7530fff5d8811894c75fc3378a5c6da77d7b8 (diff)
Typos. A bunch of typos I've been collecting.
Change-Id: I53ab8d17914e6563110354e4052109ac02bf8f3b Signed-off-by: Paul Vinciguerra <pvinci@vinciconsulting.com>
Diffstat (limited to 'src/vnet/bier')
-rw-r--r--src/vnet/bier/bier_bit_string.c2
-rw-r--r--src/vnet/bier/bier_disp_entry.c10
-rw-r--r--src/vnet/bier/bier_fmask.c4
-rw-r--r--src/vnet/bier/bier_fmask_db.c6
-rw-r--r--src/vnet/bier/bier_imp.c2
-rw-r--r--src/vnet/bier/bier_imp_node.c2
-rw-r--r--src/vnet/bier/bier_input.c2
-rw-r--r--src/vnet/bier/bier_lookup.c2
-rw-r--r--src/vnet/bier/bier_output.c6
-rw-r--r--src/vnet/bier/bier_table.c4
10 files changed, 20 insertions, 20 deletions
diff --git a/src/vnet/bier/bier_bit_string.c b/src/vnet/bier/bier_bit_string.c
index c22a24286e8..24546fa94c2 100644
--- a/src/vnet/bier/bier_bit_string.c
+++ b/src/vnet/bier/bier_bit_string.c
@@ -41,7 +41,7 @@ bier_bit_pos_is_valid (bier_bp_t bp, const bier_bit_string_t *bbs)
}
/*
- * Validate a bit poistion
+ * Validate a bit position
*/
#define BIER_BIT_POS_IS_VALID(_bp, _str) \
{ \
diff --git a/src/vnet/bier/bier_fmask.c b/src/vnet/bier/bier_fmask.c
index 1ca8a2e1df9..b6169d3c4bb 100644
--- a/src/vnet/bier/bier_fmask.c
+++ b/src/vnet/bier/bier_fmask.c
@@ -311,7 +311,7 @@ bier_fmask_link (index_t bfmi,
if (0 == bfm->bfm_bits.bfmb_refs[BIER_BP_TO_INDEX(bp)])
{
/*
- * 0 -> 1 transistion - set the bit in the string
+ * 0 -> 1 transition - set the bit in the string
*/
bier_bit_string_set_bit(&bfm->bfm_bits.bfmb_input_reset_string, bp);
}
@@ -334,7 +334,7 @@ bier_fmask_unlink (index_t bfmi,
if (0 == bfm->bfm_bits.bfmb_refs[BIER_BP_TO_INDEX(bp)])
{
/*
- * 1 -> 0 transistion - clear the bit in the string
+ * 1 -> 0 transition - clear the bit in the string
*/
bier_bit_string_clear_bit(&bfm->bfm_bits.bfmb_input_reset_string, bp);
}
diff --git a/src/vnet/bier/bier_imp.c b/src/vnet/bier/bier_imp.c
index 6150ea1c067..2da3f668cac 100644
--- a/src/vnet/bier/bier_imp.c
+++ b/src/vnet/bier/bier_imp.c
@@ -17,7 +17,7 @@
*
* A BIER imposition object is present in the IP mcast output list
* and represents the imposition of a BIER bitmask. After BIER header
- * imposition the packet is forward within the appropriate/specifid
+ * imposition the packet is forward within the appropriate/specified
* BIER table
*/
diff --git a/src/vnet/bier/bier_imp_node.c b/src/vnet/bier/bier_imp_node.c
index 5e3b3fb065f..727e92ec145 100644
--- a/src/vnet/bier/bier_imp_node.c
+++ b/src/vnet/bier/bier_imp_node.c
@@ -144,7 +144,7 @@ bier_imp_dpo_inline (vlib_main_t * vm,
/*
* use TTL 64 for the post enacp MPLS label/BIFT-ID
- * this we be decremeted in bier_output node.
+ * this we be decremented in bier_output node.
*/
vnet_buffer(b0)->mpls.ttl = 65;
diff --git a/src/vnet/bier/bier_input.c b/src/vnet/bier/bier_input.c
index dca990d07f6..d95df84ab11 100644
--- a/src/vnet/bier/bier_input.c
+++ b/src/vnet/bier/bier_input.c
@@ -107,7 +107,7 @@ bier_input (vlib_main_t * vm,
bier_hdr_ntoh(bh0);
/*
- * In the MPLS decap node we squirelled away the
+ * In the MPLS decap node we squirrelled away the
* index for the BIER table as the tx adjacency
*/
bt_index0 = vnet_buffer(b0)->ip.adj_index[VLIB_TX];
diff --git a/src/vnet/bier/bier_lookup.c b/src/vnet/bier/bier_lookup.c
index 51011c98008..c57c81d7aa9 100644
--- a/src/vnet/bier/bier_lookup.c
+++ b/src/vnet/bier/bier_lookup.c
@@ -22,7 +22,7 @@
#include <vnet/bier/bier_fmask.h>
/**
- * Struct maintining the per-worker thread data for BIER lookups
+ * Struct maintaining the per-worker thread data for BIER lookups
*/
typedef struct bier_lookup_main_t_
{
diff --git a/src/vnet/bier/bier_output.c b/src/vnet/bier/bier_output.c
index e2cf7d62cee..5c19103d6a3 100644
--- a/src/vnet/bier/bier_output.c
+++ b/src/vnet/bier/bier_output.c
@@ -26,7 +26,7 @@ static char * bier_output_error_strings[] = {
};
/*
- * Keep these values sematically the same as BIER output
+ * Keep these values semantically the same as BIER output
*/
#define foreach_bier_output_next \
_(DROP, "bier-drop")
@@ -52,7 +52,7 @@ vlib_node_registration_t bier_output_node;
extern vlib_combined_counter_main_t bier_fmask_counters;
/**
- * @brief Packet trace recoed for a BIER output
+ * @brief Packet trace record for a BIER output
*/
typedef struct bier_output_trace_t_
{
@@ -109,7 +109,7 @@ bier_output (vlib_main_t * vm,
bier_bit_string_init_from_hdr(bh0, &bbs);
/*
- * In the BIER Lookup node we squirelled away the
+ * In the BIER Lookup node we squirrelled away the
* BIER fmask index as the adj index
*/
bfmi0 = vnet_buffer (b0)->ip.adj_index[VLIB_TX];
diff --git a/src/vnet/bier/bier_table.c b/src/vnet/bier/bier_table.c
index edfb754ecc1..a9f8a6d338f 100644
--- a/src/vnet/bier/bier_table.c
+++ b/src/vnet/bier/bier_table.c
@@ -251,7 +251,7 @@ bier_table_mk_lfib (bier_table_t *bt)
FIB_SOURCE_BIER);
/*
- * stack the entry on the forwarding chain prodcued by the
+ * stack the entry on the forwarding chain produced by the
* path-list via the ECMP tables.
*/
fib_path_list_contribute_forwarding(bt->bt_pl,
@@ -309,7 +309,7 @@ bier_table_mk_ecmp (index_t bti)
}
/*
- * no oppotunity to share, this the resolving ECMP tables are unique
+ * no opportunity to share, this the resolving ECMP tables are unique
* to this table.
* no need to be a child of the path list, we can do nothing with any
* notifications it would generate [not that it will].
diff --git a/src/vnet/bier/bier_disp_entry.c b/src/vnet/bier/bier_disp_entry.c
index 2df8314dc09..98508addfe0 100644
--- a/src/vnet/bier/bier_disp_entry.c
+++ b/src/vnet/bier/bier_disp_entry.c
@@ -13,11 +13,11 @@
* limitations under the License.
*/
/**
* bier_dispositon : The BIER dispositon object
*
* A BIER dispositon object is present in the IP mcast output list
* and represents the dispositon of a BIER bitmask. After BIER header
* dispositon the packet is forward within the appropriate/specifid
* BIER table
*/
@@ -315,7 +315,7 @@ bier_disp_entry_dpo_unlock (dpo_id_t *dpo)
static void
bier_disp_entry_dpo_mem_show (void)
{
- fib_show_memory_usage("BIER dispositon",
+ fib_show_memory_usage("BIER disposition",
pool_elts(bier_disp_entry_pool),
pool_len(bier_disp_entry_pool),
sizeof(bier_disp_entry_t));
@@ -13,11 +13,11 @@
*/
/**
- * bier_dispositon : The BIER dispositon object
+ * bier_dispositon : The BIER disposition object
*
@@ -13,11 +13,11 @@
*
- * A BIER dispositon object is present in the IP mcast output list
- * and represents the dispositon of a BIER bitmask. After BIER header
- * dispositon the packet is forward within the appropriate/specifid
+ * A BIER disposition object is present in the IP mcast output list
+ * and represents the disposition of a BIER bitmask. After BIER header
+ * disposition the packet is forward within the appropriate/specified
* BIER table
*/
diff --git a/src/vnet/bier/bier_fmask_db.c b/src/vnet/bier/bier_fmask_db.c
index 0ee1e5d6bf8..d0f5ba1c18e 100644
--- a/src/vnet/bier/bier_fmask_db.c
+++ b/src/vnet/bier/bier_fmask_db.c
@@ -25,7 +25,7 @@
*
* The table's key is part of this DB key, since the fmasks therein build up
* their forwarding mask based on the routes that resolve through
- * it, so cross polination would be bad.
+ * it, so cross pollination would be bad.
*/
typedef struct bier_fmask_db_t_ {
/**
@@ -143,9 +143,9 @@ bier_fmask_db_remove (const bier_fmask_id_t *fmid)
if (NULL == p) {
/*
* remove a non-exitant entry - oops
*/
- ASSERT (!"remove non-existant fmask");
+ ASSERT (!"remove non-existent fmask");
} else {
hash_unset(bier_fmask_db.bfdb_hash, fmid);
}
@@ -143,9 +143,9 @@ bier_fmask_db_remove (const bier_fmask_id_t *fmid)
if (NULL == p) {
/*
- * remove a non-exitant entry - oops
+ * remove a non-existent entry - oops
*/